# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.file_record_list_response_m import FileRecordListResponseM

class TestFileRecordListResponseM(unittest.TestCase):
    """FileRecordListResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileRecordListResponseM:
        """Test FileRecordListResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileRecordListResponseM`
        """
        model = FileRecordListResponseM()
        if include_optional:
            return FileRecordListResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                file_records = [
                    onboarding_buddy_client.models.file_record_m.FileRecordM(
                        global_id = '', 
                        organisation_global_id = '', 
                        application_global_id = '', 
                        file_name = '', 
                        mime_type = '', 
                        origin_type = '', 
                        original_file_name = '', 
                        file_size = 56, 
                        file_status = '', 
                        title = '', 
                        description = '', 
                        tags = '', 
                        reasoning = '', 
                        created_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return FileRecordListResponseM(
        )
        """

    def testFileRecordListResponseM(self):
        """Test FileRecordListResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
