# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.file_upload_response_m import FileUploadResponseM

class TestFileUploadResponseM(unittest.TestCase):
    """FileUploadResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileUploadResponseM:
        """Test FileUploadResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FileUploadResponseM`
        """
        model = FileUploadResponseM()
        if include_optional:
            return FileUploadResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                global_id = '',
                organisation_global_id = '',
                application_global_id = '',
                file_name = '',
                mime_type = '',
                file_size = 56,
                file_status = '',
                active = True
            )
        else:
            return FileUploadResponseM(
        )
        """

    def testFileUploadResponseM(self):
        """Test FileUploadResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
