# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.aircraft_sanctions_check_response_m import AircraftSanctionsCheckResponseM

class TestAircraftSanctionsCheckResponseM(unittest.TestCase):
    """AircraftSanctionsCheckResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AircraftSanctionsCheckResponseM:
        """Test AircraftSanctionsCheckResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AircraftSanctionsCheckResponseM`
        """
        model = AircraftSanctionsCheckResponseM()
        if include_optional:
            return AircraftSanctionsCheckResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                matched = True,
                match = [
                    onboarding_buddy_client.models.aircraft_sanction_record_m.AircraftSanctionRecordM(
                        full_name = '', 
                        program = '', 
                        manufacture_date = '', 
                        model = '', 
                        operator = '', 
                        manufacturer_serial_number = '', 
                        tail_number = '', 
                        construction_number = '', 
                        previous_tail_number = '', 
                        mode_s_transponder_code = '', 
                        serial_identification = '', 
                        additional_info = [
                            ''
                            ], 
                        alias_list = [
                            onboarding_buddy_client.models.individual_alias_m.IndividualAliasM(
                                full_name = '', 
                                first_name = '', 
                                last_name = '', 
                                remarks = '', )
                            ], 
                        address_list = [
                            onboarding_buddy_client.models.individual_address_m.IndividualAddressM(
                                address = '', 
                                city_state_province_postal_code = '', 
                                country = '', 
                                address_remarks = '', )
                            ], 
                        nationality = '', 
                        linked_to = '', 
                        secondary_sanctions_risk = '', 
                        also_known_as = [
                            ''
                            ], 
                        linked_individuals = [
                            onboarding_buddy_client.models.email_individual_record_m.EmailIndividualRecordM(
                                full_name = '', 
                                first_name = '', 
                                last_name = '', 
                                program = '', 
                                title = '', 
                                nationality = '', 
                                gender = '', 
                                linked_to = '', 
                                secondary_sanctions_risk = '', 
                                digital_currency_address = [
                                    onboarding_buddy_client.models.digital_currency_address_m.DigitalCurrencyAddressM(
                                        instrument = '', 
                                        address = '', )
                                    ], 
                                websites = [
                                    ''
                                    ], 
                                email_address = [
                                    ''
                                    ], )
                            ], 
                        linked_entity = [
                            onboarding_buddy_client.models.other_sanction_record_m.OtherSanctionRecordM(
                                full_name = '', 
                                program = '', 
                                title = '', 
                                nationality = '', 
                                linked_to = '', 
                                place_of_birth = '', 
                                passport = '', 
                                citizen = '', 
                                national_id_number = '', 
                                secondary_sanctions_risk = '', 
                                call_sign = '', 
                                vessel_type = '', 
                                tonnage = '', 
                                grt = '', 
                                vessel_flag = '', 
                                vessel_owner = '', )
                            ], )
                    ]
            )
        else:
            return AircraftSanctionsCheckResponseM(
        )
        """

    def testAircraftSanctionsCheckResponseM(self):
        """Test AircraftSanctionsCheckResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
