# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.file_api import FileApi


class TestFileApi(unittest.TestCase):
    """FileApi unit test stubs"""

    def setUp(self) -> None:
        self.api = FileApi()

    def tearDown(self) -> None:
        pass

    def test_document_rag(self) -> None:
        """Test case for document_rag

        Document RAG
        """
        pass

    def test_download(self) -> None:
        """Test case for download

        File Download
        """
        pass

    def test_get_file_record(self) -> None:
        """Test case for get_file_record

        Get File
        """
        pass

    def test_get_file_records(self) -> None:
        """Test case for get_file_records

        Get Files
        """
        pass

    def test_search_file_records(self) -> None:
        """Test case for search_file_records

        Search Files
        """
        pass

    def test_upload(self) -> None:
        """Test case for upload

        File Upload
        """
        pass


if __name__ == '__main__':
    unittest.main()
