# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.batch_api import BatchApi


class TestBatchApi(unittest.TestCase):
    """BatchApi unit test stubs"""

    def setUp(self) -> None:
        self.api = BatchApi()

    def tearDown(self) -> None:
        pass

    def test_get_browser_batch(self) -> None:
        """Test case for get_browser_batch

        Get the results for a batch - browser
        """
        pass

    def test_get_emailaddress_batch(self) -> None:
        """Test case for get_emailaddress_batch

        Get the results for a batch - email address
        """
        pass

    def test_get_ipaddress_batch(self) -> None:
        """Test case for get_ipaddress_batch

        Get the results for a batch - ip address
        """
        pass

    def test_get_mobilenumber_batch(self) -> None:
        """Test case for get_mobilenumber_batch

        Get the results for a batch - mobile number
        """
        pass

    def test_poll_batch(self) -> None:
        """Test case for poll_batch

        Poll the state of a batch submitted for processing
        """
        pass

    def test_submit_browser_batch(self) -> None:
        """Test case for submit_browser_batch

        Perform browser validation for a batch of values
        """
        pass

    def test_submit_emailaddress_batch(self) -> None:
        """Test case for submit_emailaddress_batch

        Perform email address validation for a batch of values
        """
        pass

    def test_submit_ipaddress_batch(self) -> None:
        """Test case for submit_ipaddress_batch

        Perform ip address validation for a batch of values
        """
        pass

    def test_submit_mobilenumber_batch(self) -> None:
        """Test case for submit_mobilenumber_batch

        Perform mobile number validation for a batch of values
        """
        pass


if __name__ == '__main__':
    unittest.main()
