# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.models.ip_address_get_batch_response_m import IpAddressGetBatchResponseM

class TestIpAddressGetBatchResponseM(unittest.TestCase):
    """IpAddressGetBatchResponseM unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> IpAddressGetBatchResponseM:
        """Test IpAddressGetBatchResponseM
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `IpAddressGetBatchResponseM`
        """
        model = IpAddressGetBatchResponseM()
        if include_optional:
            return IpAddressGetBatchResponseM(
                message_id = '',
                correlation_id = '',
                idempotency_key = '',
                in_error = True,
                error_type = '',
                messages = [
                    ''
                    ],
                batch_id = '',
                batch_status = '',
                batch_size = 56,
                batch_type = '',
                created_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                processed_count = 56,
                error_count = 56,
                result_data = [
                    {"ipAddress":"18.230.227.254","isoCode":"BR","country":"Brazil","threat":"unknown","riskLevel":"1","checkStatus":"Matched"}
                    ]
            )
        else:
            return IpAddressGetBatchResponseM(
        )
        """

    def testIpAddressGetBatchResponseM(self):
        """Test IpAddressGetBatchResponseM"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
