# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.validation_api import ValidationApi


class TestValidationApi(unittest.TestCase):
    """ValidationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ValidationApi()

    def tearDown(self) -> None:
        pass

    def test_browser(self) -> None:
        """Test case for browser

        Perform a browser validation
        """
        pass

    def test_email(self) -> None:
        """Test case for email

        Perform an email validation
        """
        pass

    def test_ipaddress(self) -> None:
        """Test case for ipaddress

        Perform an ip address validation
        """
        pass

    def test_mobile(self) -> None:
        """Test case for mobile

        Perform a mobile validation
        """
        pass


if __name__ == '__main__':
    unittest.main()
