# coding: utf-8

"""
    Onboarding Buddy API

    This document details all the available operations in the Onboarding Buddy API specification

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from onboarding_buddy_client.api.sanctions_api import SanctionsApi


class TestSanctionsApi(unittest.TestCase):
    """SanctionsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = SanctionsApi()

    def tearDown(self) -> None:
        pass

    def test_aircraft(self) -> None:
        """Test case for aircraft

        Perform an aircraft sanctions check
        """
        pass

    def test_crypto_wallet(self) -> None:
        """Test case for crypto_wallet

        Perform a crypto wallet sanctions check
        """
        pass

    def test_entity(self) -> None:
        """Test case for entity

        Perform an entity sanctions check
        """
        pass

    def test_individual(self) -> None:
        """Test case for individual

        Perform an individual sanctions list check
        """
        pass

    def test_vessel(self) -> None:
        """Test case for vessel

        Perform a vessel sanctions check
        """
        pass


if __name__ == '__main__':
    unittest.main()
